# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class LightningappInstanceServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def lightningapp_instance_service_complete_multipart_upload_project_artifact(self, body: 'MultipartCompleteBody', project_id: 'str', **kwargs) -> 'V1CompleteMultipartUploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_complete_multipart_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_complete_multipart_upload_project_artifact(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MultipartCompleteBody body: (required)
        :param str project_id: (required)
        :return: V1CompleteMultipartUploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_complete_multipart_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_complete_multipart_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_complete_multipart_upload_project_artifact_with_http_info(self, body: 'MultipartCompleteBody', project_id: 'str', **kwargs) -> 'V1CompleteMultipartUploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_complete_multipart_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_complete_multipart_upload_project_artifact_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MultipartCompleteBody body: (required)
        :param str project_id: (required)
        :return: V1CompleteMultipartUploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_complete_multipart_upload_project_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_complete_multipart_upload_project_artifact`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_complete_multipart_upload_project_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/storage/multipart/complete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CompleteMultipartUploadProjectArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_complete_upload_project_artifact(self, body: 'StorageCompleteBody', project_id: 'str', **kwargs) -> 'V1CompleteUploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_complete_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_complete_upload_project_artifact(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StorageCompleteBody body: (required)
        :param str project_id: (required)
        :return: V1CompleteUploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_complete_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_complete_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_complete_upload_project_artifact_with_http_info(self, body: 'StorageCompleteBody', project_id: 'str', **kwargs) -> 'V1CompleteUploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_complete_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_complete_upload_project_artifact_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StorageCompleteBody body: (required)
        :param str project_id: (required)
        :return: V1CompleteUploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_complete_upload_project_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_complete_upload_project_artifact`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_complete_upload_project_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/storage/complete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CompleteUploadProjectArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_create_multipart_upload_project_artifact(self, body: 'StorageMultipartBody', project_id: 'str', **kwargs) -> 'V1CreateMultipartUploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_create_multipart_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_create_multipart_upload_project_artifact(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StorageMultipartBody body: (required)
        :param str project_id: (required)
        :return: V1CreateMultipartUploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_create_multipart_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_create_multipart_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_create_multipart_upload_project_artifact_with_http_info(self, body: 'StorageMultipartBody', project_id: 'str', **kwargs) -> 'V1CreateMultipartUploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_create_multipart_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_create_multipart_upload_project_artifact_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StorageMultipartBody body: (required)
        :param str project_id: (required)
        :return: V1CreateMultipartUploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_create_multipart_upload_project_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_create_multipart_upload_project_artifact`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_create_multipart_upload_project_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/storage/multipart', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CreateMultipartUploadProjectArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_delete_lightningapp_instance(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappInstanceResponse':  # noqa: E501
        """lightningapp_instance_service_delete_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_delete_lightningapp_instance(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteLightningappInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_delete_lightningapp_instance_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_delete_lightningapp_instance_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_delete_lightningapp_instance_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappInstanceResponse':  # noqa: E501
        """lightningapp_instance_service_delete_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_delete_lightningapp_instance_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteLightningappInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_delete_lightningapp_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_delete_lightningapp_instance`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_delete_lightningapp_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteLightningappInstanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_delete_lightningapp_instance_artifact(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappInstanceArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_delete_lightningapp_instance_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_delete_lightningapp_instance_artifact(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str filename:
        :return: V1DeleteLightningappInstanceArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_delete_lightningapp_instance_artifact_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_delete_lightningapp_instance_artifact_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_delete_lightningapp_instance_artifact_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappInstanceArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_delete_lightningapp_instance_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_delete_lightningapp_instance_artifact_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str filename:
        :return: V1DeleteLightningappInstanceArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'filename']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_delete_lightningapp_instance_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_delete_lightningapp_instance_artifact`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_delete_lightningapp_instance_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/artifacts', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteLightningappInstanceArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_delete_project_artifact(self, project_id: 'str', **kwargs) -> 'V1DeleteProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_delete_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_delete_project_artifact(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str cluster_id:
        :param str filename:
        :return: V1DeleteProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_delete_project_artifact_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_delete_project_artifact_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_delete_project_artifact_with_http_info(self, project_id: 'str', **kwargs) -> 'V1DeleteProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_delete_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_delete_project_artifact_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str cluster_id:
        :param str filename:
        :return: V1DeleteProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'cluster_id', 'filename']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_delete_project_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_delete_project_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'cluster_id' in params:
            query_params.append(('clusterId', params['cluster_id']))  # noqa: E501
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/storage', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteProjectArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_download_lightningapp_instance_logs(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DownloadLightningappInstanceLogsResponse':  # noqa: E501
        """lightningapp_instance_service_download_lightningapp_instance_logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_download_lightningapp_instance_logs(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str work_id:
        :return: V1DownloadLightningappInstanceLogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_download_lightningapp_instance_logs_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_download_lightningapp_instance_logs_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_download_lightningapp_instance_logs_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DownloadLightningappInstanceLogsResponse':  # noqa: E501
        """lightningapp_instance_service_download_lightningapp_instance_logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_download_lightningapp_instance_logs_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str work_id:
        :return: V1DownloadLightningappInstanceLogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'work_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_download_lightningapp_instance_logs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_download_lightningapp_instance_logs`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_download_lightningapp_instance_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'work_id' in params:
            query_params.append(('workId', params['work_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/download-logs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DownloadLightningappInstanceLogsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_find_lightningapp_instance(self, project_id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_find_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_find_lightningapp_instance(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str name:
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_find_lightningapp_instance_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_find_lightningapp_instance_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_find_lightningapp_instance_with_http_info(self, project_id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_find_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_find_lightningapp_instance_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str name:
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_find_lightningapp_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_find_lightningapp_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/find', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_get_lightningapp_instance(self, project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_get_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_get_lightningapp_instance(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_get_lightningapp_instance_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_get_lightningapp_instance_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_get_lightningapp_instance_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_get_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_get_lightningapp_instance_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_get_lightningapp_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_get_lightningapp_instance`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_get_lightningapp_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_get_lightningapp_instance_logs(self, project_id: 'str', id: 'str', **kwargs) -> 'V1LogsResponse':  # noqa: E501
        """lightningapp_instance_service_get_lightningapp_instance_logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_get_lightningapp_instance_logs(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str since:
        :param str until:
        :return: V1LogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_get_lightningapp_instance_logs_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_get_lightningapp_instance_logs_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_get_lightningapp_instance_logs_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1LogsResponse':  # noqa: E501
        """lightningapp_instance_service_get_lightningapp_instance_logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_get_lightningapp_instance_logs_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str since:
        :param str until:
        :return: V1LogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'since', 'until']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_get_lightningapp_instance_logs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_get_lightningapp_instance_logs`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_get_lightningapp_instance_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'since' in params:
            query_params.append(('since', params['since']))  # noqa: E501
        if 'until' in params:
            query_params.append(('until', params['until']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/page-logs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LogsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_get_lightningapp_instance_system_metrics(self, project_id: 'str', id: 'str', **kwargs) -> 'V1GetLightningappInstanceSystemMetricsResponse':  # noqa: E501
        """lightningapp_instance_service_get_lightningapp_instance_system_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_get_lightningapp_instance_system_metrics(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param list[str] work_ids:
        :param datetime start:
        :param datetime end:
        :param str frequency:
        :param bool first_query:
        :return: V1GetLightningappInstanceSystemMetricsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_get_lightningapp_instance_system_metrics_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_get_lightningapp_instance_system_metrics_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_get_lightningapp_instance_system_metrics_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1GetLightningappInstanceSystemMetricsResponse':  # noqa: E501
        """lightningapp_instance_service_get_lightningapp_instance_system_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_get_lightningapp_instance_system_metrics_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param list[str] work_ids:
        :param datetime start:
        :param datetime end:
        :param str frequency:
        :param bool first_query:
        :return: V1GetLightningappInstanceSystemMetricsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'work_ids', 'start', 'end', 'frequency', 'first_query']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_get_lightningapp_instance_system_metrics" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_get_lightningapp_instance_system_metrics`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_get_lightningapp_instance_system_metrics`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'work_ids' in params:
            query_params.append(('workIds', params['work_ids']))  # noqa: E501
            collection_formats['workIds'] = 'multi'  # noqa: E501
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'end' in params:
            query_params.append(('end', params['end']))  # noqa: E501
        if 'frequency' in params:
            query_params.append(('frequency', params['frequency']))  # noqa: E501
        if 'first_query' in params:
            query_params.append(('firstQuery', params['first_query']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/system-metrics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetLightningappInstanceSystemMetricsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_list_lightningapp_instance_artifacts(self, project_id: 'str', id: 'str', **kwargs) -> 'V1ListLightningappInstanceArtifactsResponse':  # noqa: E501
        """lightningapp_instance_service_list_lightningapp_instance_artifacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_lightningapp_instance_artifacts(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str filename:
        :param str page_token:
        :param str page_size:
        :return: V1ListLightningappInstanceArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_list_lightningapp_instance_artifacts_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_list_lightningapp_instance_artifacts_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_list_lightningapp_instance_artifacts_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1ListLightningappInstanceArtifactsResponse':  # noqa: E501
        """lightningapp_instance_service_list_lightningapp_instance_artifacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_lightningapp_instance_artifacts_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str filename:
        :param str page_token:
        :param str page_size:
        :return: V1ListLightningappInstanceArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'filename', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_list_lightningapp_instance_artifacts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_list_lightningapp_instance_artifacts`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_list_lightningapp_instance_artifacts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/artifacts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListLightningappInstanceArtifactsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_list_lightningapp_instance_events(self, project_id: 'str', id: 'str', **kwargs) -> 'V1ListLightningappInstanceEventsResponse':  # noqa: E501
        """lightningapp_instance_service_list_lightningapp_instance_events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_lightningapp_instance_events(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param bool include_costs:
        :return: V1ListLightningappInstanceEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_list_lightningapp_instance_events_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_list_lightningapp_instance_events_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_list_lightningapp_instance_events_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1ListLightningappInstanceEventsResponse':  # noqa: E501
        """lightningapp_instance_service_list_lightningapp_instance_events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_lightningapp_instance_events_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param bool include_costs:
        :return: V1ListLightningappInstanceEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'include_costs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_list_lightningapp_instance_events" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_list_lightningapp_instance_events`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_list_lightningapp_instance_events`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'include_costs' in params:
            query_params.append(('includeCosts', params['include_costs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListLightningappInstanceEventsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_list_lightningapp_instances(self, project_id: 'str', **kwargs) -> 'V1ListLightningappInstancesResponse':  # noqa: E501
        """lightningapp_instance_service_list_lightningapp_instances  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_lightningapp_instances(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str page_token: Pagination.
        :param str limit:
        :param list[str] user_ids: Filters.
        :param str cluster_id:
        :param list[str] phase_in:
        :param list[str] phase_not_in:
        :param str app_id:
        :param str release_id:
        :return: V1ListLightningappInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_list_lightningapp_instances_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_list_lightningapp_instances_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_list_lightningapp_instances_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListLightningappInstancesResponse':  # noqa: E501
        """lightningapp_instance_service_list_lightningapp_instances  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_lightningapp_instances_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str page_token: Pagination.
        :param str limit:
        :param list[str] user_ids: Filters.
        :param str cluster_id:
        :param list[str] phase_in:
        :param list[str] phase_not_in:
        :param str app_id:
        :param str release_id:
        :return: V1ListLightningappInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_token', 'limit', 'user_ids', 'cluster_id', 'phase_in', 'phase_not_in', 'app_id', 'release_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_list_lightningapp_instances" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_list_lightningapp_instances`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'user_ids' in params:
            query_params.append(('userIds', params['user_ids']))  # noqa: E501
            collection_formats['userIds'] = 'multi'  # noqa: E501
        if 'cluster_id' in params:
            query_params.append(('clusterId', params['cluster_id']))  # noqa: E501
        if 'phase_in' in params:
            query_params.append(('phaseIn', params['phase_in']))  # noqa: E501
            collection_formats['phaseIn'] = 'multi'  # noqa: E501
        if 'phase_not_in' in params:
            query_params.append(('phaseNotIn', params['phase_not_in']))  # noqa: E501
            collection_formats['phaseNotIn'] = 'multi'  # noqa: E501
        if 'app_id' in params:
            query_params.append(('appId', params['app_id']))  # noqa: E501
        if 'release_id' in params:
            query_params.append(('releaseId', params['release_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListLightningappInstancesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_list_project_artifacts(self, project_id: 'str', **kwargs) -> 'V1ListProjectArtifactsResponse':  # noqa: E501
        """lightningapp_instance_service_list_project_artifacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_project_artifacts(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str cluster_id:
        :param str page_token:
        :param str page_size:
        :param str prefix:
        :param bool include_download_url:
        :return: V1ListProjectArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_list_project_artifacts_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_list_project_artifacts_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_list_project_artifacts_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListProjectArtifactsResponse':  # noqa: E501
        """lightningapp_instance_service_list_project_artifacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_list_project_artifacts_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str cluster_id:
        :param str page_token:
        :param str page_size:
        :param str prefix:
        :param bool include_download_url:
        :return: V1ListProjectArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'cluster_id', 'page_token', 'page_size', 'prefix', 'include_download_url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_list_project_artifacts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_list_project_artifacts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'cluster_id' in params:
            query_params.append(('clusterId', params['cluster_id']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'prefix' in params:
            query_params.append(('prefix', params['prefix']))  # noqa: E501
        if 'include_download_url' in params:
            query_params.append(('includeDownloadUrl', params['include_download_url']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/storage', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListProjectArtifactsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_restart_lightningapp_instance(self, project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_restart_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_restart_lightningapp_instance(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_restart_lightningapp_instance_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_restart_lightningapp_instance_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_restart_lightningapp_instance_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_restart_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_restart_lightningapp_instance_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_restart_lightningapp_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_restart_lightningapp_instance`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_restart_lightningapp_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/restart', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_update_lightningapp_instance(self, body: 'AppinstancesIdBody', project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_update_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_update_lightningapp_instance(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AppinstancesIdBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_update_lightningapp_instance_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_update_lightningapp_instance_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_update_lightningapp_instance_with_http_info(self, body: 'AppinstancesIdBody', project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_update_lightningapp_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_update_lightningapp_instance_with_http_info(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AppinstancesIdBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_update_lightningapp_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_update_lightningapp_instance`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_update_lightningapp_instance`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_update_lightningapp_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_update_lightningapp_instance_release(self, body: 'IdReleaseBody', project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_update_lightningapp_instance_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_update_lightningapp_instance_release(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdReleaseBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_update_lightningapp_instance_release_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_update_lightningapp_instance_release_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_update_lightningapp_instance_release_with_http_info(self, body: 'IdReleaseBody', project_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_instance_service_update_lightningapp_instance_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_update_lightningapp_instance_release_with_http_info(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdReleaseBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_update_lightningapp_instance_release" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_update_lightningapp_instance_release`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_update_lightningapp_instance_release`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_update_lightningapp_instance_release`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/release', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_upload_lightningapp_instance_artifact(self, body: 'IdArtifactsBody', project_id: 'str', id: 'str', **kwargs) -> 'V1UploadLightningappInstanceArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_upload_lightningapp_instance_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_upload_lightningapp_instance_artifact(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdArtifactsBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1UploadLightningappInstanceArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_upload_lightningapp_instance_artifact_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_upload_lightningapp_instance_artifact_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_upload_lightningapp_instance_artifact_with_http_info(self, body: 'IdArtifactsBody', project_id: 'str', id: 'str', **kwargs) -> 'V1UploadLightningappInstanceArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_upload_lightningapp_instance_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_upload_lightningapp_instance_artifact_with_http_info(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdArtifactsBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1UploadLightningappInstanceArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_upload_lightningapp_instance_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_upload_lightningapp_instance_artifact`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_upload_lightningapp_instance_artifact`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_instance_service_upload_lightningapp_instance_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appinstances/{id}/artifacts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UploadLightningappInstanceArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_instance_service_upload_project_artifact(self, body: 'ProjectIdStorageBody', project_id: 'str', **kwargs) -> 'V1UploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_upload_project_artifact(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdStorageBody body: (required)
        :param str project_id: (required)
        :return: V1UploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_instance_service_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_instance_service_upload_project_artifact_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_instance_service_upload_project_artifact_with_http_info(self, body: 'ProjectIdStorageBody', project_id: 'str', **kwargs) -> 'V1UploadProjectArtifactResponse':  # noqa: E501
        """lightningapp_instance_service_upload_project_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_instance_service_upload_project_artifact_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdStorageBody body: (required)
        :param str project_id: (required)
        :return: V1UploadProjectArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_instance_service_upload_project_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_instance_service_upload_project_artifact`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_instance_service_upload_project_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/storage', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UploadProjectArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1Metadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annotations': 'dict(str, str)',
        'creation_timestamp': 'datetime',
        'deletion_timestamp': 'datetime',
        'display_name': 'str',
        'finalizers': 'list[str]',
        'id': 'str',
        'labels': 'dict(str, str)',
        'last_updated_by_user_at': 'datetime',
        'name': 'str',
        'project_id': 'str',
        'resource_version': 'str',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'annotations': 'annotations',
        'creation_timestamp': 'creationTimestamp',
        'deletion_timestamp': 'deletionTimestamp',
        'display_name': 'displayName',
        'finalizers': 'finalizers',
        'id': 'id',
        'labels': 'labels',
        'last_updated_by_user_at': 'lastUpdatedByUserAt',
        'name': 'name',
        'project_id': 'projectId',
        'resource_version': 'resourceVersion',
        'updated_at': 'updatedAt'
    }

    def __init__(self, annotations: 'dict(str, str)' =None, creation_timestamp: 'datetime' =None, deletion_timestamp: 'datetime' =None, display_name: 'str' =None, finalizers: 'list[str]' =None, id: 'str' =None, labels: 'dict(str, str)' =None, last_updated_by_user_at: 'datetime' =None, name: 'str' =None, project_id: 'str' =None, resource_version: 'str' =None, updated_at: 'datetime' =None):  # noqa: E501
        """V1Metadata - a model defined in Swagger"""  # noqa: E501
        self._annotations = None
        self._creation_timestamp = None
        self._deletion_timestamp = None
        self._display_name = None
        self._finalizers = None
        self._id = None
        self._labels = None
        self._last_updated_by_user_at = None
        self._name = None
        self._project_id = None
        self._resource_version = None
        self._updated_at = None
        self.discriminator = None
        if annotations is not None:
            self.annotations = annotations
        if creation_timestamp is not None:
            self.creation_timestamp = creation_timestamp
        if deletion_timestamp is not None:
            self.deletion_timestamp = deletion_timestamp
        if display_name is not None:
            self.display_name = display_name
        if finalizers is not None:
            self.finalizers = finalizers
        if id is not None:
            self.id = id
        if labels is not None:
            self.labels = labels
        if last_updated_by_user_at is not None:
            self.last_updated_by_user_at = last_updated_by_user_at
        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if resource_version is not None:
            self.resource_version = resource_version
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def annotations(self) -> 'dict(str, str)':
        """Gets the annotations of this V1Metadata.  # noqa: E501


        :return: The annotations of this V1Metadata.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations: 'dict(str, str)'):
        """Sets the annotations of this V1Metadata.


        :param annotations: The annotations of this V1Metadata.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def creation_timestamp(self) -> 'datetime':
        """Gets the creation_timestamp of this V1Metadata.  # noqa: E501


        :return: The creation_timestamp of this V1Metadata.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_timestamp

    @creation_timestamp.setter
    def creation_timestamp(self, creation_timestamp: 'datetime'):
        """Sets the creation_timestamp of this V1Metadata.


        :param creation_timestamp: The creation_timestamp of this V1Metadata.  # noqa: E501
        :type: datetime
        """

        self._creation_timestamp = creation_timestamp

    @property
    def deletion_timestamp(self) -> 'datetime':
        """Gets the deletion_timestamp of this V1Metadata.  # noqa: E501


        :return: The deletion_timestamp of this V1Metadata.  # noqa: E501
        :rtype: datetime
        """
        return self._deletion_timestamp

    @deletion_timestamp.setter
    def deletion_timestamp(self, deletion_timestamp: 'datetime'):
        """Sets the deletion_timestamp of this V1Metadata.


        :param deletion_timestamp: The deletion_timestamp of this V1Metadata.  # noqa: E501
        :type: datetime
        """

        self._deletion_timestamp = deletion_timestamp

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1Metadata.  # noqa: E501


        :return: The display_name of this V1Metadata.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1Metadata.


        :param display_name: The display_name of this V1Metadata.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def finalizers(self) -> 'list[str]':
        """Gets the finalizers of this V1Metadata.  # noqa: E501


        :return: The finalizers of this V1Metadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._finalizers

    @finalizers.setter
    def finalizers(self, finalizers: 'list[str]'):
        """Sets the finalizers of this V1Metadata.


        :param finalizers: The finalizers of this V1Metadata.  # noqa: E501
        :type: list[str]
        """

        self._finalizers = finalizers

    @property
    def id(self) -> 'str':
        """Gets the id of this V1Metadata.  # noqa: E501


        :return: The id of this V1Metadata.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1Metadata.


        :param id: The id of this V1Metadata.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def labels(self) -> 'dict(str, str)':
        """Gets the labels of this V1Metadata.  # noqa: E501

        (Could) provide filtering options for list/watch requests, not implemented.  # noqa: E501

        :return: The labels of this V1Metadata.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels: 'dict(str, str)'):
        """Sets the labels of this V1Metadata.

        (Could) provide filtering options for list/watch requests, not implemented.  # noqa: E501

        :param labels: The labels of this V1Metadata.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def last_updated_by_user_at(self) -> 'datetime':
        """Gets the last_updated_by_user_at of this V1Metadata.  # noqa: E501


        :return: The last_updated_by_user_at of this V1Metadata.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_by_user_at

    @last_updated_by_user_at.setter
    def last_updated_by_user_at(self, last_updated_by_user_at: 'datetime'):
        """Sets the last_updated_by_user_at of this V1Metadata.


        :param last_updated_by_user_at: The last_updated_by_user_at of this V1Metadata.  # noqa: E501
        :type: datetime
        """

        self._last_updated_by_user_at = last_updated_by_user_at

    @property
    def name(self) -> 'str':
        """Gets the name of this V1Metadata.  # noqa: E501


        :return: The name of this V1Metadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1Metadata.


        :param name: The name of this V1Metadata.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1Metadata.  # noqa: E501


        :return: The project_id of this V1Metadata.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1Metadata.


        :param project_id: The project_id of this V1Metadata.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def resource_version(self) -> 'str':
        """Gets the resource_version of this V1Metadata.  # noqa: E501


        :return: The resource_version of this V1Metadata.  # noqa: E501
        :rtype: str
        """
        return self._resource_version

    @resource_version.setter
    def resource_version(self, resource_version: 'str'):
        """Sets the resource_version of this V1Metadata.


        :param resource_version: The resource_version of this V1Metadata.  # noqa: E501
        :type: str
        """

        self._resource_version = resource_version

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1Metadata.  # noqa: E501


        :return: The updated_at of this V1Metadata.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1Metadata.


        :param updated_at: The updated_at of this V1Metadata.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Metadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Metadata') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Metadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1Metadata') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1SLURMJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloudspace_id': 'str',
        'cluster_id': 'str',
        'command': 'str',
        'created_at': 'datetime',
        'id': 'str',
        'message': 'str',
        'name': 'str',
        'project_id': 'str',
        'run_id': 'str',
        'slurm_v1_status': 'V1SlurmV1JobStatus',
        'state': 'str',
        'updated_at': 'datetime',
        'upload_eta_seconds': 'str',
        'upload_in_progress': 'bool',
        'upload_percentage': 'str',
        'user_id': 'str',
        'work_dir': 'str'
    }

    attribute_map = {
        'cloudspace_id': 'cloudspaceId',
        'cluster_id': 'clusterId',
        'command': 'command',
        'created_at': 'createdAt',
        'id': 'id',
        'message': 'message',
        'name': 'name',
        'project_id': 'projectId',
        'run_id': 'runId',
        'slurm_v1_status': 'slurmV1Status',
        'state': 'state',
        'updated_at': 'updatedAt',
        'upload_eta_seconds': 'uploadEtaSeconds',
        'upload_in_progress': 'uploadInProgress',
        'upload_percentage': 'uploadPercentage',
        'user_id': 'userId',
        'work_dir': 'workDir'
    }

    def __init__(self, cloudspace_id: 'str' =None, cluster_id: 'str' =None, command: 'str' =None, created_at: 'datetime' =None, id: 'str' =None, message: 'str' =None, name: 'str' =None, project_id: 'str' =None, run_id: 'str' =None, slurm_v1_status: 'V1SlurmV1JobStatus' =None, state: 'str' =None, updated_at: 'datetime' =None, upload_eta_seconds: 'str' =None, upload_in_progress: 'bool' =None, upload_percentage: 'str' =None, user_id: 'str' =None, work_dir: 'str' =None):  # noqa: E501
        """V1SLURMJob - a model defined in Swagger"""  # noqa: E501
        self._cloudspace_id = None
        self._cluster_id = None
        self._command = None
        self._created_at = None
        self._id = None
        self._message = None
        self._name = None
        self._project_id = None
        self._run_id = None
        self._slurm_v1_status = None
        self._state = None
        self._updated_at = None
        self._upload_eta_seconds = None
        self._upload_in_progress = None
        self._upload_percentage = None
        self._user_id = None
        self._work_dir = None
        self.discriminator = None
        if cloudspace_id is not None:
            self.cloudspace_id = cloudspace_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if command is not None:
            self.command = command
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if message is not None:
            self.message = message
        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if run_id is not None:
            self.run_id = run_id
        if slurm_v1_status is not None:
            self.slurm_v1_status = slurm_v1_status
        if state is not None:
            self.state = state
        if updated_at is not None:
            self.updated_at = updated_at
        if upload_eta_seconds is not None:
            self.upload_eta_seconds = upload_eta_seconds
        if upload_in_progress is not None:
            self.upload_in_progress = upload_in_progress
        if upload_percentage is not None:
            self.upload_percentage = upload_percentage
        if user_id is not None:
            self.user_id = user_id
        if work_dir is not None:
            self.work_dir = work_dir

    @property
    def cloudspace_id(self) -> 'str':
        """Gets the cloudspace_id of this V1SLURMJob.  # noqa: E501


        :return: The cloudspace_id of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._cloudspace_id

    @cloudspace_id.setter
    def cloudspace_id(self, cloudspace_id: 'str'):
        """Sets the cloudspace_id of this V1SLURMJob.


        :param cloudspace_id: The cloudspace_id of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._cloudspace_id = cloudspace_id

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1SLURMJob.  # noqa: E501


        :return: The cluster_id of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1SLURMJob.


        :param cluster_id: The cluster_id of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def command(self) -> 'str':
        """Gets the command of this V1SLURMJob.  # noqa: E501


        :return: The command of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command: 'str'):
        """Sets the command of this V1SLURMJob.


        :param command: The command of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1SLURMJob.  # noqa: E501


        :return: The created_at of this V1SLURMJob.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1SLURMJob.


        :param created_at: The created_at of this V1SLURMJob.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self) -> 'str':
        """Gets the id of this V1SLURMJob.  # noqa: E501


        :return: The id of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1SLURMJob.


        :param id: The id of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def message(self) -> 'str':
        """Gets the message of this V1SLURMJob.  # noqa: E501


        :return: The message of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1SLURMJob.


        :param message: The message of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def name(self) -> 'str':
        """Gets the name of this V1SLURMJob.  # noqa: E501


        :return: The name of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1SLURMJob.


        :param name: The name of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1SLURMJob.  # noqa: E501


        :return: The project_id of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1SLURMJob.


        :param project_id: The project_id of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def run_id(self) -> 'str':
        """Gets the run_id of this V1SLURMJob.  # noqa: E501


        :return: The run_id of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id: 'str'):
        """Sets the run_id of this V1SLURMJob.


        :param run_id: The run_id of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def slurm_v1_status(self) -> 'V1SlurmV1JobStatus':
        """Gets the slurm_v1_status of this V1SLURMJob.  # noqa: E501


        :return: The slurm_v1_status of this V1SLURMJob.  # noqa: E501
        :rtype: V1SlurmV1JobStatus
        """
        return self._slurm_v1_status

    @slurm_v1_status.setter
    def slurm_v1_status(self, slurm_v1_status: 'V1SlurmV1JobStatus'):
        """Sets the slurm_v1_status of this V1SLURMJob.


        :param slurm_v1_status: The slurm_v1_status of this V1SLURMJob.  # noqa: E501
        :type: V1SlurmV1JobStatus
        """

        self._slurm_v1_status = slurm_v1_status

    @property
    def state(self) -> 'str':
        """Gets the state of this V1SLURMJob.  # noqa: E501


        :return: The state of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state: 'str'):
        """Sets the state of this V1SLURMJob.


        :param state: The state of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1SLURMJob.  # noqa: E501


        :return: The updated_at of this V1SLURMJob.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1SLURMJob.


        :param updated_at: The updated_at of this V1SLURMJob.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def upload_eta_seconds(self) -> 'str':
        """Gets the upload_eta_seconds of this V1SLURMJob.  # noqa: E501


        :return: The upload_eta_seconds of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._upload_eta_seconds

    @upload_eta_seconds.setter
    def upload_eta_seconds(self, upload_eta_seconds: 'str'):
        """Sets the upload_eta_seconds of this V1SLURMJob.


        :param upload_eta_seconds: The upload_eta_seconds of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._upload_eta_seconds = upload_eta_seconds

    @property
    def upload_in_progress(self) -> 'bool':
        """Gets the upload_in_progress of this V1SLURMJob.  # noqa: E501


        :return: The upload_in_progress of this V1SLURMJob.  # noqa: E501
        :rtype: bool
        """
        return self._upload_in_progress

    @upload_in_progress.setter
    def upload_in_progress(self, upload_in_progress: 'bool'):
        """Sets the upload_in_progress of this V1SLURMJob.


        :param upload_in_progress: The upload_in_progress of this V1SLURMJob.  # noqa: E501
        :type: bool
        """

        self._upload_in_progress = upload_in_progress

    @property
    def upload_percentage(self) -> 'str':
        """Gets the upload_percentage of this V1SLURMJob.  # noqa: E501


        :return: The upload_percentage of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._upload_percentage

    @upload_percentage.setter
    def upload_percentage(self, upload_percentage: 'str'):
        """Sets the upload_percentage of this V1SLURMJob.


        :param upload_percentage: The upload_percentage of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._upload_percentage = upload_percentage

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1SLURMJob.  # noqa: E501


        :return: The user_id of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1SLURMJob.


        :param user_id: The user_id of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def work_dir(self) -> 'str':
        """Gets the work_dir of this V1SLURMJob.  # noqa: E501

        Where the files will be downloaded, for example: /scratch/nyu/<username> Then the directories that Lightning will create/use: /scratch/nyu/<username>/lightning_manager/<studio name>/<job-id>/...  # noqa: E501

        :return: The work_dir of this V1SLURMJob.  # noqa: E501
        :rtype: str
        """
        return self._work_dir

    @work_dir.setter
    def work_dir(self, work_dir: 'str'):
        """Sets the work_dir of this V1SLURMJob.

        Where the files will be downloaded, for example: /scratch/nyu/<username> Then the directories that Lightning will create/use: /scratch/nyu/<username>/lightning_manager/<studio name>/<job-id>/...  # noqa: E501

        :param work_dir: The work_dir of this V1SLURMJob.  # noqa: E501
        :type: str
        """

        self._work_dir = work_dir

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1SLURMJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1SLURMJob') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SLURMJob):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1SLURMJob') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1Quotas(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'free_storage_bytes': 'str',
        'max_frontends_per_lightning_app': 'str',
        'max_lightning_app_releases': 'str',
        'max_lightning_apps': 'str',
        'max_lightning_works': 'str',
        'max_running_default_lightning_works_per_app': 'str',
        'max_running_lightning_apps': 'str',
        'max_running_lightning_works': 'str'
    }

    attribute_map = {
        'free_storage_bytes': 'freeStorageBytes',
        'max_frontends_per_lightning_app': 'maxFrontendsPerLightningApp',
        'max_lightning_app_releases': 'maxLightningAppReleases',
        'max_lightning_apps': 'maxLightningApps',
        'max_lightning_works': 'maxLightningWorks',
        'max_running_default_lightning_works_per_app': 'maxRunningDefaultLightningWorksPerApp',
        'max_running_lightning_apps': 'maxRunningLightningApps',
        'max_running_lightning_works': 'maxRunningLightningWorks'
    }

    def __init__(self, free_storage_bytes: 'str' =None, max_frontends_per_lightning_app: 'str' =None, max_lightning_app_releases: 'str' =None, max_lightning_apps: 'str' =None, max_lightning_works: 'str' =None, max_running_default_lightning_works_per_app: 'str' =None, max_running_lightning_apps: 'str' =None, max_running_lightning_works: 'str' =None):  # noqa: E501
        """V1Quotas - a model defined in Swagger"""  # noqa: E501
        self._free_storage_bytes = None
        self._max_frontends_per_lightning_app = None
        self._max_lightning_app_releases = None
        self._max_lightning_apps = None
        self._max_lightning_works = None
        self._max_running_default_lightning_works_per_app = None
        self._max_running_lightning_apps = None
        self._max_running_lightning_works = None
        self.discriminator = None
        if free_storage_bytes is not None:
            self.free_storage_bytes = free_storage_bytes
        if max_frontends_per_lightning_app is not None:
            self.max_frontends_per_lightning_app = max_frontends_per_lightning_app
        if max_lightning_app_releases is not None:
            self.max_lightning_app_releases = max_lightning_app_releases
        if max_lightning_apps is not None:
            self.max_lightning_apps = max_lightning_apps
        if max_lightning_works is not None:
            self.max_lightning_works = max_lightning_works
        if max_running_default_lightning_works_per_app is not None:
            self.max_running_default_lightning_works_per_app = max_running_default_lightning_works_per_app
        if max_running_lightning_apps is not None:
            self.max_running_lightning_apps = max_running_lightning_apps
        if max_running_lightning_works is not None:
            self.max_running_lightning_works = max_running_lightning_works

    @property
    def free_storage_bytes(self) -> 'str':
        """Gets the free_storage_bytes of this V1Quotas.  # noqa: E501


        :return: The free_storage_bytes of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._free_storage_bytes

    @free_storage_bytes.setter
    def free_storage_bytes(self, free_storage_bytes: 'str'):
        """Sets the free_storage_bytes of this V1Quotas.


        :param free_storage_bytes: The free_storage_bytes of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._free_storage_bytes = free_storage_bytes

    @property
    def max_frontends_per_lightning_app(self) -> 'str':
        """Gets the max_frontends_per_lightning_app of this V1Quotas.  # noqa: E501


        :return: The max_frontends_per_lightning_app of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_frontends_per_lightning_app

    @max_frontends_per_lightning_app.setter
    def max_frontends_per_lightning_app(self, max_frontends_per_lightning_app: 'str'):
        """Sets the max_frontends_per_lightning_app of this V1Quotas.


        :param max_frontends_per_lightning_app: The max_frontends_per_lightning_app of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_frontends_per_lightning_app = max_frontends_per_lightning_app

    @property
    def max_lightning_app_releases(self) -> 'str':
        """Gets the max_lightning_app_releases of this V1Quotas.  # noqa: E501


        :return: The max_lightning_app_releases of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_lightning_app_releases

    @max_lightning_app_releases.setter
    def max_lightning_app_releases(self, max_lightning_app_releases: 'str'):
        """Sets the max_lightning_app_releases of this V1Quotas.


        :param max_lightning_app_releases: The max_lightning_app_releases of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_lightning_app_releases = max_lightning_app_releases

    @property
    def max_lightning_apps(self) -> 'str':
        """Gets the max_lightning_apps of this V1Quotas.  # noqa: E501


        :return: The max_lightning_apps of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_lightning_apps

    @max_lightning_apps.setter
    def max_lightning_apps(self, max_lightning_apps: 'str'):
        """Sets the max_lightning_apps of this V1Quotas.


        :param max_lightning_apps: The max_lightning_apps of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_lightning_apps = max_lightning_apps

    @property
    def max_lightning_works(self) -> 'str':
        """Gets the max_lightning_works of this V1Quotas.  # noqa: E501


        :return: The max_lightning_works of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_lightning_works

    @max_lightning_works.setter
    def max_lightning_works(self, max_lightning_works: 'str'):
        """Sets the max_lightning_works of this V1Quotas.


        :param max_lightning_works: The max_lightning_works of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_lightning_works = max_lightning_works

    @property
    def max_running_default_lightning_works_per_app(self) -> 'str':
        """Gets the max_running_default_lightning_works_per_app of this V1Quotas.  # noqa: E501


        :return: The max_running_default_lightning_works_per_app of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_running_default_lightning_works_per_app

    @max_running_default_lightning_works_per_app.setter
    def max_running_default_lightning_works_per_app(self, max_running_default_lightning_works_per_app: 'str'):
        """Sets the max_running_default_lightning_works_per_app of this V1Quotas.


        :param max_running_default_lightning_works_per_app: The max_running_default_lightning_works_per_app of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_running_default_lightning_works_per_app = max_running_default_lightning_works_per_app

    @property
    def max_running_lightning_apps(self) -> 'str':
        """Gets the max_running_lightning_apps of this V1Quotas.  # noqa: E501


        :return: The max_running_lightning_apps of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_running_lightning_apps

    @max_running_lightning_apps.setter
    def max_running_lightning_apps(self, max_running_lightning_apps: 'str'):
        """Sets the max_running_lightning_apps of this V1Quotas.


        :param max_running_lightning_apps: The max_running_lightning_apps of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_running_lightning_apps = max_running_lightning_apps

    @property
    def max_running_lightning_works(self) -> 'str':
        """Gets the max_running_lightning_works of this V1Quotas.  # noqa: E501


        :return: The max_running_lightning_works of this V1Quotas.  # noqa: E501
        :rtype: str
        """
        return self._max_running_lightning_works

    @max_running_lightning_works.setter
    def max_running_lightning_works(self, max_running_lightning_works: 'str'):
        """Sets the max_running_lightning_works of this V1Quotas.


        :param max_running_lightning_works: The max_running_lightning_works of this V1Quotas.  # noqa: E501
        :type: str
        """

        self._max_running_lightning_works = max_running_lightning_works

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Quotas, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Quotas') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Quotas):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1Quotas') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class ProjectIdGetappBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'component_id': 'str',
        'env': 'list[V1EnvVar]',
        'hostname': 'str',
        'id': 'str',
        'version': 'str'
    }

    attribute_map = {
        'cluster_id': 'clusterId',
        'component_id': 'componentId',
        'env': 'env',
        'hostname': 'hostname',
        'id': 'id',
        'version': 'version'
    }

    def __init__(self, cluster_id: 'str' =None, component_id: 'str' =None, env: 'list[V1EnvVar]' =None, hostname: 'str' =None, id: 'str' =None, version: 'str' =None):  # noqa: E501
        """ProjectIdGetappBody - a model defined in Swagger"""  # noqa: E501
        self._cluster_id = None
        self._component_id = None
        self._env = None
        self._hostname = None
        self._id = None
        self._version = None
        self.discriminator = None
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if component_id is not None:
            self.component_id = component_id
        if env is not None:
            self.env = env
        if hostname is not None:
            self.hostname = hostname
        if id is not None:
            self.id = id
        if version is not None:
            self.version = version

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this ProjectIdGetappBody.  # noqa: E501


        :return: The cluster_id of this ProjectIdGetappBody.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this ProjectIdGetappBody.


        :param cluster_id: The cluster_id of this ProjectIdGetappBody.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def component_id(self) -> 'str':
        """Gets the component_id of this ProjectIdGetappBody.  # noqa: E501


        :return: The component_id of this ProjectIdGetappBody.  # noqa: E501
        :rtype: str
        """
        return self._component_id

    @component_id.setter
    def component_id(self, component_id: 'str'):
        """Sets the component_id of this ProjectIdGetappBody.


        :param component_id: The component_id of this ProjectIdGetappBody.  # noqa: E501
        :type: str
        """

        self._component_id = component_id

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this ProjectIdGetappBody.  # noqa: E501


        :return: The env of this ProjectIdGetappBody.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this ProjectIdGetappBody.


        :param env: The env of this ProjectIdGetappBody.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def hostname(self) -> 'str':
        """Gets the hostname of this ProjectIdGetappBody.  # noqa: E501


        :return: The hostname of this ProjectIdGetappBody.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname: 'str'):
        """Sets the hostname of this ProjectIdGetappBody.


        :param hostname: The hostname of this ProjectIdGetappBody.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def id(self) -> 'str':
        """Gets the id of this ProjectIdGetappBody.  # noqa: E501


        :return: The id of this ProjectIdGetappBody.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this ProjectIdGetappBody.


        :param id: The id of this ProjectIdGetappBody.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def version(self) -> 'str':
        """Gets the version of this ProjectIdGetappBody.  # noqa: E501


        :return: The version of this ProjectIdGetappBody.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this ProjectIdGetappBody.


        :param version: The version of this ProjectIdGetappBody.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectIdGetappBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'ProjectIdGetappBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectIdGetappBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'ProjectIdGetappBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ClusterAccelerator(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'accelerator_type': 'str',
        'available_in_seconds': 'str',
        'cluster_id': 'str',
        'cost': 'float',
        'device_card': 'str',
        'device_info': 'str',
        'display_name': 'str',
        'enabled': 'bool',
        'instance_id': 'str',
        'is_tier_restricted': 'bool',
        'quota_checked_at': 'datetime',
        'quota_code': 'str',
        'quota_name': 'str',
        'quota_page_url': 'str',
        'quota_service_code': 'str',
        'quota_utilization': 'str',
        'quota_value': 'str',
        'resources': 'V1Resources',
        'slug': 'str'
    }

    attribute_map = {
        'accelerator_type': 'acceleratorType',
        'available_in_seconds': 'availableInSeconds',
        'cluster_id': 'clusterId',
        'cost': 'cost',
        'device_card': 'deviceCard',
        'device_info': 'deviceInfo',
        'display_name': 'displayName',
        'enabled': 'enabled',
        'instance_id': 'instanceId',
        'is_tier_restricted': 'isTierRestricted',
        'quota_checked_at': 'quotaCheckedAt',
        'quota_code': 'quotaCode',
        'quota_name': 'quotaName',
        'quota_page_url': 'quotaPageUrl',
        'quota_service_code': 'quotaServiceCode',
        'quota_utilization': 'quotaUtilization',
        'quota_value': 'quotaValue',
        'resources': 'resources',
        'slug': 'slug'
    }

    def __init__(self, accelerator_type: 'str' =None, available_in_seconds: 'str' =None, cluster_id: 'str' =None, cost: 'float' =None, device_card: 'str' =None, device_info: 'str' =None, display_name: 'str' =None, enabled: 'bool' =None, instance_id: 'str' =None, is_tier_restricted: 'bool' =None, quota_checked_at: 'datetime' =None, quota_code: 'str' =None, quota_name: 'str' =None, quota_page_url: 'str' =None, quota_service_code: 'str' =None, quota_utilization: 'str' =None, quota_value: 'str' =None, resources: 'V1Resources' =None, slug: 'str' =None):  # noqa: E501
        """V1ClusterAccelerator - a model defined in Swagger"""  # noqa: E501
        self._accelerator_type = None
        self._available_in_seconds = None
        self._cluster_id = None
        self._cost = None
        self._device_card = None
        self._device_info = None
        self._display_name = None
        self._enabled = None
        self._instance_id = None
        self._is_tier_restricted = None
        self._quota_checked_at = None
        self._quota_code = None
        self._quota_name = None
        self._quota_page_url = None
        self._quota_service_code = None
        self._quota_utilization = None
        self._quota_value = None
        self._resources = None
        self._slug = None
        self.discriminator = None
        if accelerator_type is not None:
            self.accelerator_type = accelerator_type
        if available_in_seconds is not None:
            self.available_in_seconds = available_in_seconds
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if cost is not None:
            self.cost = cost
        if device_card is not None:
            self.device_card = device_card
        if device_info is not None:
            self.device_info = device_info
        if display_name is not None:
            self.display_name = display_name
        if enabled is not None:
            self.enabled = enabled
        if instance_id is not None:
            self.instance_id = instance_id
        if is_tier_restricted is not None:
            self.is_tier_restricted = is_tier_restricted
        if quota_checked_at is not None:
            self.quota_checked_at = quota_checked_at
        if quota_code is not None:
            self.quota_code = quota_code
        if quota_name is not None:
            self.quota_name = quota_name
        if quota_page_url is not None:
            self.quota_page_url = quota_page_url
        if quota_service_code is not None:
            self.quota_service_code = quota_service_code
        if quota_utilization is not None:
            self.quota_utilization = quota_utilization
        if quota_value is not None:
            self.quota_value = quota_value
        if resources is not None:
            self.resources = resources
        if slug is not None:
            self.slug = slug

    @property
    def accelerator_type(self) -> 'str':
        """Gets the accelerator_type of this V1ClusterAccelerator.  # noqa: E501


        :return: The accelerator_type of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._accelerator_type

    @accelerator_type.setter
    def accelerator_type(self, accelerator_type: 'str'):
        """Sets the accelerator_type of this V1ClusterAccelerator.


        :param accelerator_type: The accelerator_type of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._accelerator_type = accelerator_type

    @property
    def available_in_seconds(self) -> 'str':
        """Gets the available_in_seconds of this V1ClusterAccelerator.  # noqa: E501


        :return: The available_in_seconds of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._available_in_seconds

    @available_in_seconds.setter
    def available_in_seconds(self, available_in_seconds: 'str'):
        """Sets the available_in_seconds of this V1ClusterAccelerator.


        :param available_in_seconds: The available_in_seconds of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._available_in_seconds = available_in_seconds

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1ClusterAccelerator.  # noqa: E501


        :return: The cluster_id of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1ClusterAccelerator.


        :param cluster_id: The cluster_id of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def cost(self) -> 'float':
        """Gets the cost of this V1ClusterAccelerator.  # noqa: E501


        :return: The cost of this V1ClusterAccelerator.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost: 'float'):
        """Sets the cost of this V1ClusterAccelerator.


        :param cost: The cost of this V1ClusterAccelerator.  # noqa: E501
        :type: float
        """

        self._cost = cost

    @property
    def device_card(self) -> 'str':
        """Gets the device_card of this V1ClusterAccelerator.  # noqa: E501


        :return: The device_card of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._device_card

    @device_card.setter
    def device_card(self, device_card: 'str'):
        """Sets the device_card of this V1ClusterAccelerator.


        :param device_card: The device_card of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._device_card = device_card

    @property
    def device_info(self) -> 'str':
        """Gets the device_info of this V1ClusterAccelerator.  # noqa: E501


        :return: The device_info of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._device_info

    @device_info.setter
    def device_info(self, device_info: 'str'):
        """Sets the device_info of this V1ClusterAccelerator.


        :param device_info: The device_info of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._device_info = device_info

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1ClusterAccelerator.  # noqa: E501


        :return: The display_name of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1ClusterAccelerator.


        :param display_name: The display_name of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def enabled(self) -> 'bool':
        """Gets the enabled of this V1ClusterAccelerator.  # noqa: E501


        :return: The enabled of this V1ClusterAccelerator.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled: 'bool'):
        """Sets the enabled of this V1ClusterAccelerator.


        :param enabled: The enabled of this V1ClusterAccelerator.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def instance_id(self) -> 'str':
        """Gets the instance_id of this V1ClusterAccelerator.  # noqa: E501


        :return: The instance_id of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id: 'str'):
        """Sets the instance_id of this V1ClusterAccelerator.


        :param instance_id: The instance_id of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def is_tier_restricted(self) -> 'bool':
        """Gets the is_tier_restricted of this V1ClusterAccelerator.  # noqa: E501


        :return: The is_tier_restricted of this V1ClusterAccelerator.  # noqa: E501
        :rtype: bool
        """
        return self._is_tier_restricted

    @is_tier_restricted.setter
    def is_tier_restricted(self, is_tier_restricted: 'bool'):
        """Sets the is_tier_restricted of this V1ClusterAccelerator.


        :param is_tier_restricted: The is_tier_restricted of this V1ClusterAccelerator.  # noqa: E501
        :type: bool
        """

        self._is_tier_restricted = is_tier_restricted

    @property
    def quota_checked_at(self) -> 'datetime':
        """Gets the quota_checked_at of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_checked_at of this V1ClusterAccelerator.  # noqa: E501
        :rtype: datetime
        """
        return self._quota_checked_at

    @quota_checked_at.setter
    def quota_checked_at(self, quota_checked_at: 'datetime'):
        """Sets the quota_checked_at of this V1ClusterAccelerator.


        :param quota_checked_at: The quota_checked_at of this V1ClusterAccelerator.  # noqa: E501
        :type: datetime
        """

        self._quota_checked_at = quota_checked_at

    @property
    def quota_code(self) -> 'str':
        """Gets the quota_code of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_code of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._quota_code

    @quota_code.setter
    def quota_code(self, quota_code: 'str'):
        """Sets the quota_code of this V1ClusterAccelerator.


        :param quota_code: The quota_code of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._quota_code = quota_code

    @property
    def quota_name(self) -> 'str':
        """Gets the quota_name of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_name of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._quota_name

    @quota_name.setter
    def quota_name(self, quota_name: 'str'):
        """Sets the quota_name of this V1ClusterAccelerator.


        :param quota_name: The quota_name of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._quota_name = quota_name

    @property
    def quota_page_url(self) -> 'str':
        """Gets the quota_page_url of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_page_url of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._quota_page_url

    @quota_page_url.setter
    def quota_page_url(self, quota_page_url: 'str'):
        """Sets the quota_page_url of this V1ClusterAccelerator.


        :param quota_page_url: The quota_page_url of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._quota_page_url = quota_page_url

    @property
    def quota_service_code(self) -> 'str':
        """Gets the quota_service_code of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_service_code of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._quota_service_code

    @quota_service_code.setter
    def quota_service_code(self, quota_service_code: 'str'):
        """Sets the quota_service_code of this V1ClusterAccelerator.


        :param quota_service_code: The quota_service_code of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._quota_service_code = quota_service_code

    @property
    def quota_utilization(self) -> 'str':
        """Gets the quota_utilization of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_utilization of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._quota_utilization

    @quota_utilization.setter
    def quota_utilization(self, quota_utilization: 'str'):
        """Sets the quota_utilization of this V1ClusterAccelerator.


        :param quota_utilization: The quota_utilization of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._quota_utilization = quota_utilization

    @property
    def quota_value(self) -> 'str':
        """Gets the quota_value of this V1ClusterAccelerator.  # noqa: E501


        :return: The quota_value of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._quota_value

    @quota_value.setter
    def quota_value(self, quota_value: 'str'):
        """Sets the quota_value of this V1ClusterAccelerator.


        :param quota_value: The quota_value of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._quota_value = quota_value

    @property
    def resources(self) -> 'V1Resources':
        """Gets the resources of this V1ClusterAccelerator.  # noqa: E501


        :return: The resources of this V1ClusterAccelerator.  # noqa: E501
        :rtype: V1Resources
        """
        return self._resources

    @resources.setter
    def resources(self, resources: 'V1Resources'):
        """Sets the resources of this V1ClusterAccelerator.


        :param resources: The resources of this V1ClusterAccelerator.  # noqa: E501
        :type: V1Resources
        """

        self._resources = resources

    @property
    def slug(self) -> 'str':
        """Gets the slug of this V1ClusterAccelerator.  # noqa: E501


        :return: The slug of this V1ClusterAccelerator.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug: 'str'):
        """Sets the slug of this V1ClusterAccelerator.


        :param slug: The slug of this V1ClusterAccelerator.  # noqa: E501
        :type: str
        """

        self._slug = slug

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ClusterAccelerator, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ClusterAccelerator') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ClusterAccelerator):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ClusterAccelerator') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
